==> openshift-model-6.13.0-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ResourceQuotaStatus;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterResourceQuotaStatusFluent<A extends ClusterResourceQuotaStatusFluent<A>> extends BaseFluent<A>{
  public ClusterResourceQuotaStatusFluent() {
  }
  
  public ClusterResourceQuotaStatusFluent(ClusterResourceQuotaStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ResourceQuotaStatusByNamespaceBuilder> namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();
  private ResourceQuotaStatus total;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterResourceQuotaStatus instance) {
    instance = (instance != null ? instance : new ClusterResourceQuotaStatus());
    if (instance != null) {
          this.withNamespaces(instance.getNamespaces());
          this.withTotal(instance.getTotal());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToNamespaces(int index,ResourceQuotaStatusByNamespace item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);
    if (index < 0 || index >= namespaces.size()) { _visitables.get("namespaces").add(builder); namespaces.add(builder); } else { _visitables.get("namespaces").add(index, builder); namespaces.add(index, builder);}
    return (A)this;
  }
  
  public A setToNamespaces(int index,ResourceQuotaStatusByNamespace item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);
    if (index < 0 || index >= namespaces.size()) { _visitables.get("namespaces").add(builder); namespaces.add(builder); } else { _visitables.get("namespaces").set(index, builder); namespaces.set(index, builder);}
    return (A)this;
  }
  
  public A addToNamespaces(io.fabric8.openshift.api.model.ResourceQuotaStatusByNamespace... items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").add(builder);this.namespaces.add(builder);} return (A)this;
  }
  
  public A addAllToNamespaces(Collection<ResourceQuotaStatusByNamespace> items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").add(builder);this.namespaces.add(builder);} return (A)this;
  }
  
  public A removeFromNamespaces(io.fabric8.openshift.api.model.ResourceQuotaStatusByNamespace... items) {
    if (this.namespaces == null) return (A)this;
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").remove(builder); this.namespaces.remove(builder);} return (A)this;
  }
  
  public A removeAllFromNamespaces(Collection<ResourceQuotaStatusByNamespace> items) {
    if (this.namespaces == null) return (A)this;
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").remove(builder); this.namespaces.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromNamespaces(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
    if (namespaces == null) return (A) this;
    final Iterator<ResourceQuotaStatusByNamespaceBuilder> each = namespaces.iterator();
    final List visitables = _visitables.get("namespaces");
    while (each.hasNext()) {
      ResourceQuotaStatusByNamespaceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ResourceQuotaStatusByNamespace> buildNamespaces() {
    return this.namespaces != null ? build(namespaces) : null;
  }
  
  public ResourceQuotaStatusByNamespace buildNamespace(int index) {
    return this.namespaces.get(index).build();
  }
  
  public ResourceQuotaStatusByNamespace buildFirstNamespace() {
    return this.namespaces.get(0).build();
  }
  
  public ResourceQuotaStatusByNamespace buildLastNamespace() {
    return this.namespaces.get(namespaces.size() - 1).build();
  }
  
  public ResourceQuotaStatusByNamespace buildMatchingNamespace(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
      for (ResourceQuotaStatusByNamespaceBuilder item : namespaces) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingNamespace(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
      for (ResourceQuotaStatusByNamespaceBuilder item : namespaces) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withNamespaces(List<ResourceQuotaStatusByNamespace> namespaces) {
    if (this.namespaces != null) {
      this._visitables.get("namespaces").clear();
    }
    if (namespaces != null) {
        this.namespaces = new ArrayList();
        for (ResourceQuotaStatusByNamespace item : namespaces) {
          this.addToNamespaces(item);
        }
    } else {
      this.namespaces = null;
    }
    return (A) this;
  }
  
  public A withNamespaces(io.fabric8.openshift.api.model.ResourceQuotaStatusByNamespace... namespaces) {
    if (this.namespaces != null) {
        this.namespaces.clear();
        _visitables.remove("namespaces");
    }
    if (namespaces != null) {
      for (ResourceQuotaStatusByNamespace item : namespaces) {
        this.addToNamespaces(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasNamespaces() {
    return this.namespaces != null && !this.namespaces.isEmpty();
  }
  
  public NamespacesNested<A> addNewNamespace() {
    return new NamespacesNested(-1, null);
  }
  
  public NamespacesNested<A> addNewNamespaceLike(ResourceQuotaStatusByNamespace item) {
    return new NamespacesNested(-1, item);
  }
  
  public NamespacesNested<A> setNewNamespaceLike(int index,ResourceQuotaStatusByNamespace item) {
    return new NamespacesNested(index, item);
  }
  
  public NamespacesNested<A> editNamespace(int index) {
    if (namespaces.size() <= index) throw new RuntimeException("Can't edit namespaces. Index exceeds size.");
    return setNewNamespaceLike(index, buildNamespace(index));
  }
  
  public NamespacesNested<A> editFirstNamespace() {
    if (namespaces.size() == 0) throw new RuntimeException("Can't edit first namespaces. The list is empty.");
    return setNewNamespaceLike(0, buildNamespace(0));
  }
  
  public NamespacesNested<A> editLastNamespace() {
    int index = namespaces.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last namespaces. The list is empty.");
    return setNewNamespaceLike(index, buildNamespace(index));
  }
  
  public NamespacesNested<A> editMatchingNamespace(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<namespaces.size();i++) { 
    if (predicate.test(namespaces.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching namespaces. No match found.");
    return setNewNamespaceLike(index, buildNamespace(index));
  }
  
  public ResourceQuotaStatus getTotal() {
    return this.total;
  }
  
  public A withTotal(ResourceQuotaStatus total) {
    this.total = total;
    return (A) this;
  }
  
  public boolean hasTotal() {
    return this.total != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterResourceQuotaStatusFluent that = (ClusterResourceQuotaStatusFluent) o;
    if (!java.util.Objects.equals(namespaces, that.namespaces)) return false;
    if (!java.util.Objects.equals(total, that.total)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(namespaces,  total,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (namespaces != null && !namespaces.isEmpty()) { sb.append("namespaces:"); sb.append(namespaces + ","); }
    if (total != null) { sb.append("total:"); sb.append(total + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class NamespacesNested<N> extends ResourceQuotaStatusByNamespaceFluent<NamespacesNested<N>> implements Nested<N>{
    NamespacesNested(int index,ResourceQuotaStatusByNamespace item) {
      this.index = index;
      this.builder = new ResourceQuotaStatusByNamespaceBuilder(this, item);
    }
    ResourceQuotaStatusByNamespaceBuilder builder;
    int index;
    
    public N and() {
      return (N) ClusterResourceQuotaStatusFluent.this.setToNamespaces(index,builder.build());
    }
    
    public N endNamespace() {
      return and();
    }
    
  
  }

}

==> openshift-model-7.4.0-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaStatusFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ResourceQuotaStatus;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterResourceQuotaStatusFluent<A extends ClusterResourceQuotaStatusFluent<A>> extends BaseFluent<A>{
  public ClusterResourceQuotaStatusFluent() {
  }
  
  public ClusterResourceQuotaStatusFluent(ClusterResourceQuotaStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<ResourceQuotaStatusByNamespaceBuilder> namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();
  private ResourceQuotaStatus total;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ClusterResourceQuotaStatus instance) {
    instance = (instance != null ? instance : new ClusterResourceQuotaStatus());
    if (instance != null) {
          this.withNamespaces(instance.getNamespaces());
          this.withTotal(instance.getTotal());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToNamespaces(int index,ResourceQuotaStatusByNamespace item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);
    if (index < 0 || index >= namespaces.size()) {
        _visitables.get("namespaces").add(builder);
        namespaces.add(builder);
    } else {
        _visitables.get("namespaces").add(builder);
        namespaces.add(index, builder);
    }
    return (A)this;
  }
  
  public A setToNamespaces(int index,ResourceQuotaStatusByNamespace item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);
    if (index < 0 || index >= namespaces.size()) {
        _visitables.get("namespaces").add(builder);
        namespaces.add(builder);
    } else {
        _visitables.get("namespaces").add(builder);
        namespaces.set(index, builder);
    }
    return (A)this;
  }
  
  public A addToNamespaces(io.fabric8.openshift.api.model.ResourceQuotaStatusByNamespace... items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").add(builder);this.namespaces.add(builder);} return (A)this;
  }
  
  public A addAllToNamespaces(Collection<ResourceQuotaStatusByNamespace> items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<ResourceQuotaStatusByNamespaceBuilder>();}
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").add(builder);this.namespaces.add(builder);} return (A)this;
  }
  
  public A removeFromNamespaces(io.fabric8.openshift.api.model.ResourceQuotaStatusByNamespace... items) {
    if (this.namespaces == null) return (A)this;
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").remove(builder); this.namespaces.remove(builder);} return (A)this;
  }
  
  public A removeAllFromNamespaces(Collection<ResourceQuotaStatusByNamespace> items) {
    if (this.namespaces == null) return (A)this;
    for (ResourceQuotaStatusByNamespace item : items) {ResourceQuotaStatusByNamespaceBuilder builder = new ResourceQuotaStatusByNamespaceBuilder(item);_visitables.get("namespaces").remove(builder); this.namespaces.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromNamespaces(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
    if (namespaces == null) return (A) this;
    final Iterator<ResourceQuotaStatusByNamespaceBuilder> each = namespaces.iterator();
    final List visitables = _visitables.get("namespaces");
    while (each.hasNext()) {
      ResourceQuotaStatusByNamespaceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<ResourceQuotaStatusByNamespace> buildNamespaces() {
    return this.namespaces != null ? build(namespaces) : null;
  }
  
  public ResourceQuotaStatusByNamespace buildNamespace(int index) {
    return this.namespaces.get(index).build();
  }
  
  public ResourceQuotaStatusByNamespace buildFirstNamespace() {
    return this.namespaces.get(0).build();
  }
  
  public ResourceQuotaStatusByNamespace buildLastNamespace() {
    return this.namespaces.get(namespaces.size() - 1).build();
  }
  
  public ResourceQuotaStatusByNamespace buildMatchingNamespace(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
      for (ResourceQuotaStatusByNamespaceBuilder item : namespaces) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingNamespace(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
      for (ResourceQuotaStatusByNamespaceBuilder item : namespaces) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withNamespaces(List<ResourceQuotaStatusByNamespace> namespaces) {
    if (this.namespaces != null) {
      this._visitables.get("namespaces").clear();
    }
    if (namespaces != null) {
        this.namespaces = new ArrayList();
        for (ResourceQuotaStatusByNamespace item : namespaces) {
          this.addToNamespaces(item);
        }
    } else {
      this.namespaces = null;
    }
    return (A) this;
  }
  
  public A withNamespaces(io.fabric8.openshift.api.model.ResourceQuotaStatusByNamespace... namespaces) {
    if (this.namespaces != null) {
        this.namespaces.clear();
        _visitables.remove("namespaces");
    }
    if (namespaces != null) {
      for (ResourceQuotaStatusByNamespace item : namespaces) {
        this.addToNamespaces(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasNamespaces() {
    return this.namespaces != null && !this.namespaces.isEmpty();
  }
  
  public NamespacesNested<A> addNewNamespace() {
    return new NamespacesNested(-1, null);
  }
  
  public NamespacesNested<A> addNewNamespaceLike(ResourceQuotaStatusByNamespace item) {
    return new NamespacesNested(-1, item);
  }
  
  public NamespacesNested<A> setNewNamespaceLike(int index,ResourceQuotaStatusByNamespace item) {
    return new NamespacesNested(index, item);
  }
  
  public NamespacesNested<A> editNamespace(int index) {
    if (namespaces.size() <= index) throw new RuntimeException("Can't edit namespaces. Index exceeds size.");
    return setNewNamespaceLike(index, buildNamespace(index));
  }
  
  public NamespacesNested<A> editFirstNamespace() {
    if (namespaces.size() == 0) throw new RuntimeException("Can't edit first namespaces. The list is empty.");
    return setNewNamespaceLike(0, buildNamespace(0));
  }
  
  public NamespacesNested<A> editLastNamespace() {
    int index = namespaces.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last namespaces. The list is empty.");
    return setNewNamespaceLike(index, buildNamespace(index));
  }
  
  public NamespacesNested<A> editMatchingNamespace(Predicate<ResourceQuotaStatusByNamespaceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<namespaces.size();i++) { 
    if (predicate.test(namespaces.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching namespaces. No match found.");
    return setNewNamespaceLike(index, buildNamespace(index));
  }
  
  public ResourceQuotaStatus getTotal() {
    return this.total;
  }
  
  public A withTotal(ResourceQuotaStatus total) {
    this.total = total;
    return (A) this;
  }
  
  public boolean hasTotal() {
    return this.total != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterResourceQuotaStatusFluent that = (ClusterResourceQuotaStatusFluent) o;
    if (!java.util.Objects.equals(namespaces, that.namespaces)) return false;
    if (!java.util.Objects.equals(total, that.total)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(namespaces,  total,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (namespaces != null && !namespaces.isEmpty()) { sb.append("namespaces:"); sb.append(namespaces + ","); }
    if (total != null) { sb.append("total:"); sb.append(total + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class NamespacesNested<N> extends ResourceQuotaStatusByNamespaceFluent<NamespacesNested<N>> implements Nested<N>{
    NamespacesNested(int index,ResourceQuotaStatusByNamespace item) {
      this.index = index;
      this.builder = new ResourceQuotaStatusByNamespaceBuilder(this, item);
    }
    ResourceQuotaStatusByNamespaceBuilder builder;
    int index;
    
    public N and() {
      return (N) ClusterResourceQuotaStatusFluent.this.setToNamespaces(index,builder.build());
    }
    
    public N endNamespace() {
      return and();
    }
    
  
  }

}
